import random
import opcua

client = opcua.Client("opc.tcp://localhost:4870/")
try:
    client.connect()

    # Client has a few methods to get proxy to UA nodes that should always be in address space such as Root or Objects
    root = client.get_root_node()
    objects = client.get_objects_node()
    print("Root node: ", root)
    print("Objects node: ", objects)

    # Node objects have methods to read and write node attributes as well as browse or populate address space
    print("\nChildren of objects: ", objects.get_children())

    # Tags
    print("\nTags: ", root.get_child(["0:Objects", "2:WinCC Panel RT", "4:Tags"]).get_children())

    # Get a specific node
    #  - from node id
    var = client.get_node("ns=4;s=SCADA_pec_senzor_temperatura")
    #  - from browse path
    var = root.get_child(["0:Objects", "2:WinCC Panel RT", "4:Tags", "4:$SCADA_pec_senzor_temperatura"])
    #  - from stacked access (caution: indices will change!)
    var = root.get_children()[0].get_children()[0].get_children()[1].get_children()[5]        

    # read variable
    print("\nVariable: ", var)
    val = var.get_data_value()
    print("Variable data all: ", val)
    print("Variable value: ", val.Value.Value)
    print("Variable value alt.: ", var.get_value())
    print("Variable status code: ", val.StatusCode.name)

    # write variable
    val.Value.Value = 100.0 + random.randint(1,20)
    print("\nSet value: ", val.Value.Value)
    var.set_value(val)        

    # read current value to a new variable    
    var2 = client.get_node("ns=4;s=SCADA_pec_senzor_temperatura")
    print("\nVariable value: ", var2.get_value())

finally:
    client.disconnect()
